<?php
/**
 * Comment Template modifications.
 *
 * @package    Community_Builder
 * @subpackage Core
 * @copyright  Copyright (c) 2018, Brajesh Singh
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     Brajesh Singh
 * @since      1.0.0
 */

// Do not allow direct access over web.
defined( 'ABSPATH' ) || exit;

/**
 * Applies cb customisations to the post comment form.
 *
 * @param array $default_labels The default options for strings, fields etc in the form.
 *
 * @see comment_form()
 * @return array
 */
function cb_filter_comment_form_defaults( $default_labels ) {

	$commenter = wp_get_current_commenter();
	$req       = get_option( 'require_name_email' );
	$aria_req  = ( $req ? " aria-required='true'" : '' );
	$fields = array(
		'author' => '<p class="comment-form-author">' . '<label for="author">' . __( 'Name', 'community-builder' ) . ( $req ? '<span class="required"> *</span>' : '' ) . '</label> ' .
		            '<input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30"' . $aria_req . ' /></p>',
		'email'  => '<p class="comment-form-email"><label for="email">' . __( 'Email', 'community-builder' ) . ( $req ? '<span class="required"> *</span>' : '' ) . '</label> ' .
		            '<input id="email" name="email" type="text" value="' . esc_attr( $commenter['comment_author_email'] ) . '" size="30"' . $aria_req . ' /></p>',
		'url'    => '<p class="comment-form-url"><label for="url">' . __( 'Website', 'community-builder' ) . '</label>' .
		            '<input id="url" name="url" type="text" value="' . esc_attr( $commenter['comment_author_url'] ) . '" size="30" /></p>',
	);

	$new_labels = array(
		'comment_field' => '<p class="form-textarea"><textarea name="comment" id="comment" cols="60" rows="10" aria-required="true"></textarea></p>',
		'fields'        => apply_filters( 'comment_form_default_fields', $fields ),
		'logged_in_as'  => '',
		'must_log_in'   => '<p class="alert">' . sprintf( __( 'You must be <a href="%1$s">logged in</a> to post a comment.', 'community-builder' ), wp_login_url( get_permalink() ) ) . '</p>',
		'title_reply'   => __( 'Leave a reply', 'community-builder' ),
	);

	return apply_filters( 'cb_comment_form_defaults', array_merge( $default_labels, $new_labels ) );
}

add_filter( 'comment_form_defaults', 'cb_filter_comment_form_defaults', 10 );
