<?php
/**
 * Styling Panel customize settings.
 *
 * @package    Community_Builder
 * @subpackage Customizer\Panels
 * @copyright  Copyright (c) 2018, Brajesh Singh
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     Brajesh Singh
 */

// Do not allow direct access over web.
defined( 'ABSPATH' ) || exit;

/**
 * Styling Panel helper.
 */
class CB_Customize_Panel_Styling {

	/**
	 * Panel Id.
	 *
	 * @var string
	 */
	private $panel = 'cb_styling';

	/**
	 * CB_Customize_Panel_Styling constructor.
	 */
	public function __construct() {
		add_filter( 'cb_customizer_sections', array( $this, 'add_sections' ) );
	}

	/**
	 * Add sections for this panel.
	 *
	 * @param array $sections sections.
	 *
	 * @return array
	 */
	public function add_sections( $sections ) {

		$new_sections = $this->get_sections();

		return array_merge( $sections, $new_sections );
	}

	/**
	 * Get all sections for this panel.
	 *
	 * @return array
	 */
	public function get_sections() {

		$panel               = $this->panel;
		$background_sections = array();

		/**
		 * Main Column
		 */
		$background_sections['styling-global'] = array(
			'priority' => 0,
			'panel'    => $panel,
			'title'    => __( 'Global', 'community-builder' ),
			'options'  => array(
				'color-group-theme-style' => array(
					'control' => array(
						'control_type' => 'CB_Customize_Control_Info_Title',
						'label'        => __( 'Color Scheme', 'community-builder' ),
					),
				),

				'theme-style' => array(
					'setting' => array(
						'sanitize_callback' => array( 'CB_Data_Sanitizer', 'sanitize_choice' ),
						'transport'         => 'postMessage',
						'default'           => 'default',
					),
					'control' => array(
						'control_type' => 'CB_Customize_Control_Preset',
						'label'        => __( 'Style', 'community-builder' ),
						'choices'      => cb_get_theme_color_palettes(),
						'description'  => __( 'Theme styles for view customization.', 'community-builder' ),
					),
				),

				'text-color' => array(
					'setting' => array(
						'sanitize_callback' => array( 'CB_Data_Sanitizer', 'sanitize_alpha_color' ),
						'transport'         => 'postMessage',
						'default'           => cb_get_default( 'text-color' ),
					),
					'control' => array(
						'control_type' => 'CB_Customize_Control_Color',
						'label'        => __( 'Text Color', 'community-builder' ),
						'description'  => __( 'Used for: most text', 'community-builder' ),
					),
				),

				'color-group-global-link' => array(
					'control' => array(
						'control_type' => 'CB_Customize_Control_Info_Title',
						'label'        => __( 'Links', 'community-builder' ),
					),
				),

				'link-color' => array(
					'setting' => array(
						'sanitize_callback' => array( 'CB_Data_Sanitizer', 'sanitize_alpha_color' ),
						'transport'         => 'postMessage',
						'default'           => cb_get_default( 'link-color' ),
					),
					'control' => array(
						'control_type' => 'CB_Customize_Control_Color',
						'label'        => __( 'Link Color', 'community-builder' ),
						'description'  => __( 'The default link color.', 'community-builder' ),
					),
				),

				'link-hover-color' => array(
					'setting' => array(
						'sanitize_callback' => array( 'CB_Data_Sanitizer', 'sanitize_alpha_color' ),
						'transport'         => 'postMessage',
						'default'           => cb_get_default( 'link-hover-color' ),
					),
					'control' => array(
						'control_type' => 'CB_Customize_Control_Color',
						'label'        => __( 'Link Hover/Focus Color', 'community-builder' ),
						'description'  => __( 'Link Hover/Focus color.', 'community-builder' ),
					),
				),
			),
		);

		$logo_options = array(
			'site-title-group-title' => array(
				'control' => array(
					'control_type' => 'CB_Customize_Control_Info_Title',
					'label'        => __( 'Site Title', 'community-builder' ),
				),
			),
		);

		$logo_options = array_merge(
			$logo_options,
			CB_Customize_Setting_Builder::get_background_settings(
				'site-title',
				array(
					'link'       => true,
					'link-hover' => true,
				)
			)
		);

		$logo_options['site-title-tagline-group-title'] = array(
			'control' => array(
				'control_type' => 'CB_Customize_Control_Info_Title',
				'label'        => __( 'Site Tagline', 'community-builder' ),
				//'active_callback' => 'cb_is_tagline_visible',
			),
		);

		$logo_options['site-tagline-text-color'] = array(
			'setting' => array(
				'sanitize_callback' => array( 'CB_Data_Sanitizer', 'sanitize_alpha_color' ),
				'transport'         => 'postMessage',
				'default'           => cb_get_default( 'site-tagline-text-color' ),
			),
			'control' => array(
				'control_type' => 'CB_Customize_Control_Color',
				'label'        => __( 'Tagline Color', 'community-builder' ),
				'description'  => __( 'Used for: site tagline', 'community-builder' ),
				//'active_callback' => 'cb_is_tagline_visible',
			),
		);

		$background_sections['styling-site-logo'] = array(
			'panel'    => $panel,
			'priority' => 6,
			'title'    => __( 'Site Title & Tagline', 'community-builder' ),
			'options'  => $logo_options,
		);

		/**
		 * Site Header
		 */

		$background_sections['header-main-styling'] = array(
			'panel'    => $panel,
			'priority' => 9,
			'title'    => __( 'Site Header', 'community-builder' ),
			'options'  => CB_Customize_Setting_Builder::get_background_settings(
				'header-main',
				array(
					'background-color' => true,
					'color'            => true,
					'link'             => true,
					'link-hover'       => true,
					'border'           => true,
				)
			),
		);

		// Main menu.
		$background_sections['styling-main-menu'] = array(
			'panel'    => $panel,
			'priority' => 9,
			'title'    => __( 'Main Menu', 'community-builder' ),
			'options'  => CB_Customize_Setting_Builder::get_menu_settings(
				'main-menu',
				array(
					'background' => true,
					'sub_menu'   => 'sub-menu',
					'alignment'  => true,
				)
			),
		);

		// for Background color , see customizer-init.php.
		$background_sections['styling-site-container-section'] = array(
			'panel'   => $panel,
			'title'   => __( 'Main area(content & sidebar container)', 'community-builder' ),
			'options' => CB_Customize_Setting_Builder::get_background_settings(
				'container',
				array(
					'background' => true,
					'border'     => true,
				)
			),
		);

		$background_sections['styling-site-content-section'] = array(
			'panel'   => $panel,
			'title'   => __( 'Contents Section', 'community-builder' ),
			'options' => array_merge(
				array(
					'content-padding' => CB_Customize_Setting_Builder::get_padding_settings(
						array(
							'label'   => __( 'Padding', 'community-builder' ),
							'default' => cb_get_default( 'content-padding' ),
						)
					),
				),
				CB_Customize_Setting_Builder::get_background_settings(
					'content',
					array(
						'background' => true,
						'color'      => true,
						'link'       => true,
						'link-hover' => true,
						'border'     => true,
					)
				)
			),
		);

		$background_sections['styling-sidebar'] = array(
			'panel'   => $panel,
			'title'   => __( 'Sidebar', 'community-builder' ),
			'options' => CB_Customize_Setting_Builder::get_panel_settings(
				'sidebar',
				array(
					'border'  => true,
					'padding' => true,
				)
			),
		);

		/**
		 * Footer
		 */
		$bg_help_link = "<a href='https://buddydev.com/community-builder/customize/site-footer-background-not-working/'>" . __( 'help', 'community-builder' ) . '</a>';

		$background_sections['styling-footer'] = array(
			'panel'   => $panel,
			'title'   => __( 'Footer', 'community-builder' ),
			'options' => CB_Customize_Setting_Builder::get_background_settings(
				'footer',
				array(
					'background'      => true,
					'border'          => true,
					'color'           => true,
					'link'            => true,
					'link-hover'      => true,
					/* translators: %s help link*/
					'background_desc' => sprintf( __( 'If the background changes are not applying, please see %s', 'community-builder' ), $bg_help_link ),
				)
			),
		);

		$footer_top_settings = CB_Customize_Setting_Builder::get_background_settings(
			'footer-top',
			array(
				'background' => true,
				'border'     => true,
				'color'      => true,
				'link'       => true,
				'link-hover' => true,
			)
		);

		$footer_top_settings = array_merge( $footer_top_settings, CB_Customize_Setting_Builder::get_widget_settings( 'footer-top-widget' ) );

		$background_sections['styling-footer-top'] = array(
			'panel'           => $panel,
			'title'           => __( 'Footer Widget Area', 'community-builder' ),
			'options'         => $footer_top_settings,
			'active_callback' => 'cb_is_site_footer_widget_area_enabled',
		);

		$background_sections['styling-site-copyright'] = array(
			'panel'   => $panel,
			'title'   => __( 'Site Copyright Area', 'community-builder' ),
			'options' => CB_Customize_Setting_Builder::get_background_settings(
				'site-copyright',
				array(
					'background-color' => true,
					'border'           => true,
					'color'            => true,
					'link'             => true,
					'link-hover'       => true,
				)
			),
		);


		$background_sections = apply_filters( 'cb_customizer_styling_sections', $background_sections );

		return $background_sections;
	}

} // end of class.

new CB_Customize_Panel_Styling();
